==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/MtlsTrustCredentials.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.MtlsTrustCredentialsRevocation;
import java.math.BigDecimal;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * MtlsTrustCredentials
 */
@JsonPropertyOrder({ MtlsTrustCredentials.JSON_PROPERTY_AUDIENCE, MtlsTrustCredentials.JSON_PROPERTY_ISSUER,
        MtlsTrustCredentials.JSON_PROPERTY_KID, MtlsTrustCredentials.JSON_PROPERTY_REVOCATION,
        MtlsTrustCredentials.JSON_PROPERTY_REVOCATION_CACHE_LIFETIME })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class MtlsTrustCredentials implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_AUDIENCE = "audience";
    private String audience;

    public static final String JSON_PROPERTY_ISSUER = "issuer";
    private String issuer;

    public static final String JSON_PROPERTY_KID = "kid";
    private String kid;

    public static final String JSON_PROPERTY_REVOCATION = "revocation";
    private MtlsTrustCredentialsRevocation revocation;

    public static final String JSON_PROPERTY_REVOCATION_CACHE_LIFETIME = "revocationCacheLifetime";
    private BigDecimal revocationCacheLifetime;

    public MtlsTrustCredentials() {
    }

    public MtlsTrustCredentials audience(String audience) {

        this.audience = audience;
        return this;
    }

    /**
     * Not used
     *
     * @return audience
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Not used")
    @JsonProperty(JSON_PROPERTY_AUDIENCE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getAudience() {
        return audience;
    }

    @JsonProperty(JSON_PROPERTY_AUDIENCE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAudience(String audience) {
        this.audience = audience;
    }

    public MtlsTrustCredentials issuer(String issuer) {

        this.issuer = issuer;
        return this;
    }

    /**
     * Description of the certificate issuer
     *
     * @return issuer
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "CN=Test Smart Card, OU=Test OU, O=Test O, C=US", value = "Description of the certificate issuer")
    @JsonProperty(JSON_PROPERTY_ISSUER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getIssuer() {
        return issuer;
    }

    @JsonProperty(JSON_PROPERTY_ISSUER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setIssuer(String issuer) {
        this.issuer = issuer;
    }

    public MtlsTrustCredentials kid(String kid) {

        this.kid = kid;
        return this;
    }

    /**
     * IdP Key Credential reference to the Okta X.509 signature certificate
     *
     * @return kid
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "your-key-id", value = "IdP Key Credential reference to the Okta X.509 signature certificate")
    @JsonProperty(JSON_PROPERTY_KID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getKid() {
        return kid;
    }

    @JsonProperty(JSON_PROPERTY_KID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setKid(String kid) {
        this.kid = kid;
    }

    public MtlsTrustCredentials revocation(MtlsTrustCredentialsRevocation revocation) {

        this.revocation = revocation;
        return this;
    }

    /**
     * Get revocation
     *
     * @return revocation
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_REVOCATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public MtlsTrustCredentialsRevocation getRevocation() {
        return revocation;
    }

    @JsonProperty(JSON_PROPERTY_REVOCATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRevocation(MtlsTrustCredentialsRevocation revocation) {
        this.revocation = revocation;
    }

    public MtlsTrustCredentials revocationCacheLifetime(BigDecimal revocationCacheLifetime) {

        this.revocationCacheLifetime = revocationCacheLifetime;
        return this;
    }

    /**
     * Time in minutes to cache the certificate revocation information maximum: 4320
     *
     * @return revocationCacheLifetime
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "2880", value = "Time in minutes to cache the certificate revocation information")
    @JsonProperty(JSON_PROPERTY_REVOCATION_CACHE_LIFETIME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public BigDecimal getRevocationCacheLifetime() {
        return revocationCacheLifetime;
    }

    @JsonProperty(JSON_PROPERTY_REVOCATION_CACHE_LIFETIME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRevocationCacheLifetime(BigDecimal revocationCacheLifetime) {
        this.revocationCacheLifetime = revocationCacheLifetime;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        MtlsTrustCredentials mtlsTrustCredentials = (MtlsTrustCredentials) o;
        return Objects.equals(this.audience, mtlsTrustCredentials.audience)
                && Objects.equals(this.issuer, mtlsTrustCredentials.issuer)
                && Objects.equals(this.kid, mtlsTrustCredentials.kid)
                && Objects.equals(this.revocation, mtlsTrustCredentials.revocation)
                && Objects.equals(this.revocationCacheLifetime, mtlsTrustCredentials.revocationCacheLifetime);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(audience, issuer, kid, revocation, revocationCacheLifetime);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class MtlsTrustCredentials {\n");
        sb.append("    audience: ").append(toIndentedString(audience)).append("\n");
        sb.append("    issuer: ").append(toIndentedString(issuer)).append("\n");
        sb.append("    kid: ").append(toIndentedString(kid)).append("\n");
        sb.append("    revocation: ").append(toIndentedString(revocation)).append("\n");
        sb.append("    revocationCacheLifetime: ").append(toIndentedString(revocationCacheLifetime)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/MtlsTrustCredentials.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.MtlsTrustCredentialsRevocation;
import java.math.BigDecimal;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * MtlsTrustCredentials
 */
@JsonPropertyOrder({ MtlsTrustCredentials.JSON_PROPERTY_AUDIENCE, MtlsTrustCredentials.JSON_PROPERTY_ISSUER,
        MtlsTrustCredentials.JSON_PROPERTY_KID, MtlsTrustCredentials.JSON_PROPERTY_REVOCATION,
        MtlsTrustCredentials.JSON_PROPERTY_REVOCATION_CACHE_LIFETIME })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class MtlsTrustCredentials implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_AUDIENCE = "audience";
    private String audience;

    public static final String JSON_PROPERTY_ISSUER = "issuer";
    private String issuer;

    public static final String JSON_PROPERTY_KID = "kid";
    private String kid;

    public static final String JSON_PROPERTY_REVOCATION = "revocation";
    private MtlsTrustCredentialsRevocation revocation;

    public static final String JSON_PROPERTY_REVOCATION_CACHE_LIFETIME = "revocationCacheLifetime";
    private BigDecimal revocationCacheLifetime;

    public MtlsTrustCredentials() {
    }

    public MtlsTrustCredentials audience(String audience) {

        this.audience = audience;
        return this;
    }

    /**
     * Not used
     *
     * @return audience
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Not used")
    @JsonProperty(JSON_PROPERTY_AUDIENCE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getAudience() {
        return audience;
    }

    @JsonProperty(JSON_PROPERTY_AUDIENCE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAudience(String audience) {
        this.audience = audience;
    }

    public MtlsTrustCredentials issuer(String issuer) {

        this.issuer = issuer;
        return this;
    }

    /**
     * Description of the certificate issuer
     *
     * @return issuer
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "CN=Test Smart Card, OU=Test OU, O=Test O, C=US", value = "Description of the certificate issuer")
    @JsonProperty(JSON_PROPERTY_ISSUER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getIssuer() {
        return issuer;
    }

    @JsonProperty(JSON_PROPERTY_ISSUER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setIssuer(String issuer) {
        this.issuer = issuer;
    }

    public MtlsTrustCredentials kid(String kid) {

        this.kid = kid;
        return this;
    }

    /**
     * IdP Key Credential reference to the Okta X.509 signature certificate
     *
     * @return kid
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "your-key-id", value = "IdP Key Credential reference to the Okta X.509 signature certificate")
    @JsonProperty(JSON_PROPERTY_KID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getKid() {
        return kid;
    }

    @JsonProperty(JSON_PROPERTY_KID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setKid(String kid) {
        this.kid = kid;
    }

    public MtlsTrustCredentials revocation(MtlsTrustCredentialsRevocation revocation) {

        this.revocation = revocation;
        return this;
    }

    /**
     * Get revocation
     *
     * @return revocation
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_REVOCATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public MtlsTrustCredentialsRevocation getRevocation() {
        return revocation;
    }

    @JsonProperty(JSON_PROPERTY_REVOCATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRevocation(MtlsTrustCredentialsRevocation revocation) {
        this.revocation = revocation;
    }

    public MtlsTrustCredentials revocationCacheLifetime(BigDecimal revocationCacheLifetime) {

        this.revocationCacheLifetime = revocationCacheLifetime;
        return this;
    }

    /**
     * Time in minutes to cache the certificate revocation information maximum: 4320
     *
     * @return revocationCacheLifetime
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "2880", value = "Time in minutes to cache the certificate revocation information")
    @JsonProperty(JSON_PROPERTY_REVOCATION_CACHE_LIFETIME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public BigDecimal getRevocationCacheLifetime() {
        return revocationCacheLifetime;
    }

    @JsonProperty(JSON_PROPERTY_REVOCATION_CACHE_LIFETIME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRevocationCacheLifetime(BigDecimal revocationCacheLifetime) {
        this.revocationCacheLifetime = revocationCacheLifetime;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        MtlsTrustCredentials mtlsTrustCredentials = (MtlsTrustCredentials) o;
        return Objects.equals(this.audience, mtlsTrustCredentials.audience)
                && Objects.equals(this.issuer, mtlsTrustCredentials.issuer)
                && Objects.equals(this.kid, mtlsTrustCredentials.kid)
                && Objects.equals(this.revocation, mtlsTrustCredentials.revocation)
                && Objects.equals(this.revocationCacheLifetime, mtlsTrustCredentials.revocationCacheLifetime);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(audience, issuer, kid, revocation, revocationCacheLifetime);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class MtlsTrustCredentials {\n");
        sb.append("    audience: ").append(toIndentedString(audience)).append("\n");
        sb.append("    issuer: ").append(toIndentedString(issuer)).append("\n");
        sb.append("    kid: ").append(toIndentedString(kid)).append("\n");
        sb.append("    revocation: ").append(toIndentedString(revocation)).append("\n");
        sb.append("    revocationCacheLifetime: ").append(toIndentedString(revocationCacheLifetime)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
